# Celo Foundation Validator Voting Policy

The following describes how the Celo Foundation anticipates allocating its votes to validator groups, with special attention to the first allocated groups at the Celo Mainnet release and the months thereafter.

{% hint style="info" %}
The policy described here can change at any time as determined by the Foundation Board.
{% endhint %}

## Policy Objectives

The Foundation voting policy aims to:
* Be fair by avoiding preferential treatment to certain groups;
* Vote in-line with the Foundation’s purpose, which is to encourage financial inclusion and prosperity for all;
* Encourage professional, secure, and reliable validators;
* Be equal opportunity by enabling new groups to have validators elected; and
* Promote network stability by encouraging a gradual turnover in elected validators instead of abrupt election changes

## Process

Every 3 months, the Foundation, through its Board, will distribute a portion of its total available votes to a cohort of validator groups. These validators must meet certain basic standards (details below) and alignment with the Foundation’s purpose. The total number of validator groups in a cohort can vary.

Validator groups who will be selected for a cohort (and will thus receive a portion of the Foundation’s votes) will be informed by the following (non-exhaustive) considerations:

1. The number of elected validators in earlier cohorts;
2. Network stability;
3. CELO governance participation (e.g., how many CELO holders are actively participating in voting); and
4. The quality of validator group applicants

Each validator group selected in the cohort will receive a portion of the Foundation votes for a period of 9 months. During this period, so long as a validator in the group is not slashed or otherwise engages in misbehavior, the validator group will continue to receive these votes. If the validator group is slashed or engages in misbehavior, however, the votes for that validator group will be withdrawn for the remainder of the period. If the validator group is slashed, it may reapply to the Foundation after a 6 month period. In addition, the Foundation may also withdraw its votes if the validator group or the validators in the group fail to meet other standards, including running an attestation service.

![](https://storage.googleapis.com/celo-website/docs/celo-foundation-cohorts.jpg)

## Eligibility Criteria 

### Standard Criteria 

To support effective and responsible validators, the Foundation considers the following, basic criteria, which must be met by all applicants who receive Foundation votes:

* **Zero Slashing Incidents.**  The validator members of any applying group must not have been slashed within the last 6 months of application. (Note, there are a variety of reasons for slashing, including downtime, security issues, etc. At the outset, and because groups can re-apply at 6 months and 1 day of the slashing, all slashing will be considered equal at this stage)

* **Audit Checklist and Self Reporting.** As part of the application process, the Foundation will publish a list of recommended validator settings. The members of every group applying will self attest to complying with the recommended checklist. 

* **Education.** An effective validator must be secure. Applicants’ members will take an education course. The course must be completed annually. 

* **Basic Diligence.** Because the Foundation holds a substantial number of votes, and its voting may determine whether a validator is elected, the Foundation will conduct a basic diligence process for voted groups. The diligence would include name, location, entity information. This diligence would occur on an annual basis for any group receiving votes. 

* **Attestation Service.** Ability and commitment to running attestation services.

* **Performance.** Performance uptime score over the past 30 days on Mainnet (or Baklava if not elected on Mainnet)

* **Attestation Performance.** Attestation Performance (attestations fulfilled / requests served) over the past 30 days on Mainnet (or Baklava if not elected Mainnet)

### Additional Criteria

In addition to meeting the standard criteria, outlined above, the Foundation anticipates prioritizing validator groups who are mission aligned and/or will provide greater network resilience. These criteria may include:

* The geographical location of the validator group

* Non-profit organizations

* Organizations who commit to donating a percentage of rewards to non-profit organizations

* The likelihood of the validator group having substantial network support from other voters

#### Notes On Improving Your Standard Criteria

* More points are given to those who have performed an external security audit on their infrastructure over those who have self-audited.

* If you are NOT ELECTED on Mainnet, you must be validating on Baklava testnet for at least 30 days. If you are ELECTED you must run validators and attestation service for at least one month (30 days) on  Mainnet. If you are ELECTED on mainnet but for less than 30 days, you must be validating on Baklava for 30 days at least.

* Mission statement and community contributions may make a big difference in whether your application is approved or not.

## Application

{% hint style="danger" %}
Make sure to complete all prerequisites before applying. 
{% endhint %}

{% hint style="info" %}
Note: Application for Cohort 7 is now open.
{% endhint %}


[APPLY FOR FOUNDATION VOTES HERE](https://forum.celo.org/t/cohort-7-application-of-foundation-voting-program-is-now-open/829)

### Timings
Cohort 7 application deadline: **April 10, 2021 at 23:59 UTC**

Anticipated vote date for selected applicants in Cohort 7: **May 1, 2021**

{% hint style="info" %}
Note: The anticipated vote date for new cohorts is a best-guess estimate given the requirements and coordination when it comes to voting for new applicants. 
{% endhint %}



### Application Prerequisites
Before applying all validator group members should have: 
* Completed the [Mastering the Art of Validating](https://youtu.be/3UIudzzCb8o) and [Validator Group Marketing](https://www.youtube.com/watch?v=0_veGIugCGQ) courses
* Completed the [Security Self Assessment Audit](https://docs.google.com/presentation/d/e/2PACX-1vRdKNpXI2mvqwQF6L5LRrxPW2qRK-5MDce5EhqXqLC1MSYmupZMFnhp6YEP0gLYuRKW-FF0fcAqhEAp/pub?start=true&loop=false&delayms=10000&slide=id.g76d52a0216_0_333), which includes completing this [checklist](https://docs.google.com/spreadsheets/d/1FqmUfleCoyNIUep7PoVu3ujHd-OkHZJ8o6p7Affr93w/edit?usp=sharing)
* Run at least one Validator and Validator Group on Mainnet or Baklava
* Run an Attestation Service on either Mainnet or Baklava

### Application Details 
Before applying be ready to share the following:
* A personal statement telling the Foundation why your group should get votes (max 1,500 characters)
* Validator Group details: email, name, website, address on Mainnet and Baklava, and geographic location
* Information about your team: full names, link to professional profiles such as LinkedIn or GitHub, and an explanation of the team’s relevant experience
* Whether your Group: 
    * Is validating or has validated in the past 1 month on the Celo Mainnet
    * Is currently receiving Foundation votes
    * Has been slashed in the past 6 months and if so why
    * Members have all completed the online training (see prerequisites)
    * Members have all completed the self-audit (see prerequisites)
    * Is a non-profit organization or donates to such organizations
    * Is a Foundation grant recipient
    * Is running or has run in the past 1 month a Validator on the Baklava testnet
* Optional: 
    * The list of contributions made to the Celo ecosystem
    * Date, audit firm name, and report of your last security audit if your Group has been audited by an external firm in the past 12 months

### Cohort Information

Past Foundation votes recipients:
* **Cohort 1:** The Great Celo Stake Off [leaderboard](https://docs.google.com/spreadsheets/d/1Me56YkCHYmsN23gSMgDb1hZ_ezN0sTjNW4kyGbAO9vc/edit#gid=1970613133) participants at ranking 26-50 -- votes will expire on Aug 1, 2020
* **Cohort 2:** The Great Celo Stake Off [leaderboard](https://docs.google.com/spreadsheets/d/1Me56YkCHYmsN23gSMgDb1hZ_ezN0sTjNW4kyGbAO9vc/edit#gid=1970613133) participants at ranking 1-25 -- votes will expire on Nov 1, 2020
* **Cohort 3:** [6 validator groups](https://docs.google.com/spreadsheets/d/1OkWnr6EOeFn4pIv0zxmXFNtHLmKWf_qCJOJ4iacov-A/edit?usp=sharing) -- votes will expire on Feb 1, 2021

Currently receiving Foundation votes: 
* **Cohort 4:** [22 validator groups](https://docs.google.com/spreadsheets/d/1bp2nJUxqhWner-uOffBohKQc3N93e--eMpP7XOBrbGI/edit?usp=sharing) -- votes will expire on May 1, 2021
* **Cohort 5:** [25 validator groups](https://docs.google.com/spreadsheets/d/1n2lwFsAsFaohng4Bo_FEWcoXzZl5CrLFxA6EK0nuFSA/edit#gid=0) -- votes will expire on Aug 1, 2021 
* **Cohort 6:** [7 validator groups](https://docs.google.com/spreadsheets/d/1HT_fN-mSAL2etF0Po_h122jeU1zpEtdpb_khogOfBCg/edit?usp=sharing) -- votes will expire on Nov 1, 2021

{% hint style="info" %}
If you would like to keep up-to-date with all the news happening in the Celo community, including validation, node operation and governance, please sign up to our [Celo Signal mailing list here](https://celo.activehosted.com/f/15).

You can add the [Celo Signal public calendar](https://calendar.google.com/calendar/u/0/embed?src=c_9su6ich1uhmetr4ob3sij6kaqs@group.calendar.google.com) as well which has relevant dates.
{% endhint %}
